@@ -109,7 +109,8 @@
 #' These values correspond to the number of parameters to be estimated.
 #' \code{family}, an object of class family specifying the distribution
 #' and link function.
-#' \code{Vp}, the variance-covariance matrix for the coefficients.
+#' \code{cholHn}, the inverse of the variance-covariance matrix for the
+#' coefficients.
 #' \code{smooth}, a list with the information about number of segments
 #' (nseg), degree of the B-spline basis (bdeg) and penalty order (pord)
 #' used for the three levels of the hierarchy.
@@ -599,7 +600,7 @@ fitSplineHDM <- function(inDat,
          convergence = convergence,
          dim = np,
          family = family,
-         Vp = spam::chol2inv(cholHn),
+         cholHn = cholHn,
          smooth = list(smoothPop = smoothPop, smoothGeno = smoothGeno,
                        smoothPlot = smoothPlot)),
     class = c("psHDM", "list"),
